@@ -17,12 +17,12 @@
  *
  *********************************************************************/
 
+#include <sbuild/sbuild-nostream.h>
+
 #include <cstdlib>
 
 #include <cppunit/extensions/HelperMacros.h>
 
-#include <schroot/sbuild-nostream.h>
-
 using namespace CppUnit;
 
 class test_nostream : public TestCase
@@ -42,9 +42,3 @@ public:
 };
 
 CPPUNIT_TEST_SUITE_REGISTRATION(test_nostream);
-
-/*
- * Local Variables:
- * mode:C++
- * End:
- */
